@@ -58,7 +58,7 @@ public:
 	ListT<Chain> schema;
 
 	schema.Insert("First:30");
-	schema.Insert("SecondColumn:auto");
+	// schema.Insert("SecondColumn:auto");
 	schema.Insert("Third:15");
 	schema.Insert("Fourth:40");
 
@@ -79,17 +79,17 @@ public:
 		ListT<Chain> outRow;
 		outRow.Insert(Chain(i) + Chain(" Alpha") ); 
 		outRow.Insert(Chain("Beta") + Chain(i) + Chain("BetaX")); 
-		outRow.Insert("Gamma1Gamma2\nGamma3");
+		// outRow.Insert("Gamma1Gamma2\nGamma3");
 		outRow.Insert("A long column XXXXXX with more data"); 
 		outData.Insert(outRow); 
 	    }
 	    
-	    for ( int i=1; i<= 3; i++) 
+	    for ( int i=1; i<= 30; i++) 
 	    { 
 		ListT<Chain> outRow;
 		outRow.Insert(Chain(i) + Chain(" Bingo") ); 
 		outRow.Insert(Chain("HalloBeta") + Chain(i) + Chain("BetaX")); 
-		outRow.Insert("XXXX\nERNA");
+		// outRow.Insert("XXXX\nERNA");
 		outRow.Insert("A long column XXXXXX with more data"); 
 		outData.Insert(outRow); 
 	    }
