@@ -41,8 +41,13 @@ int main(int argc, char **argv)
 	    Chain target;
 	    
 	    Chain str1("AlphaBeta123#hugokommt");
+	    
+	    // unsigned long nmatch =
+	    rep.replace(str1, target);
 
-	    int nmatch = rep.replace(str1, target);
+	    // cout << "nmatch = " << nmatch << endl;
+
+	    // cout << "target = " << target << endl;
 	    
 	    if ( target == Chain("AlphaBeta123") )
 		cout << "ok " << checkCount << " - First replace test" << endl;
@@ -66,8 +71,9 @@ int main(int argc, char **argv)
 	    
 	    Chain str1("MyPre:HuxBBB");
 
-	    int nmatch = rep.replace(str1, target);
-	    
+	    // unsigned long nmatch =
+	    rep.replace(str1, target);
+
 	    if ( target == Chain("MyPre:AlphaHuxXHuxBetaBBB") )
 		cout << "ok " << checkCount << " - First replace test" << endl;
 	    else
@@ -88,7 +94,8 @@ int main(int argc, char **argv)
 	    
 	    Chain str1("MyPre:HuxBBB");
 
-	    int nmatch = rep.replace(str1, target);
+	    // unsigned long  nmatch =
+	    rep.replace(str1, target);
 	    
 	    if ( target == Chain("MyPre:AlphaBetaBBB") )
 		cout << "ok " << checkCount << " - Second replace test" << endl;
@@ -111,7 +118,8 @@ int main(int argc, char **argv)
 	    
 	    Chain str1("MyPre:AlphaLong->Beta->Gamma:MyPost");
 	    
-	    int nmatch = rep.replace(str1, target);
+	    // unsigned long nmatch =
+	    rep.replace(str1, target);
 	    
 	    // cout << "Place=" << target << endl;
 	    if ( target == Chain("MyPre:PRE Second=Beta First=AlphaLong Third=Gamma POST:MyPost") )
@@ -135,7 +143,8 @@ int main(int argc, char **argv)
 	    rep.prepare();
 	    
 	    Chain target = Chain();
-	    int nmatch = rep.replace(str2, target);
+	    // unsigned long  nmatch =
+	    rep.replace(str2, target);
 	    
 	    // cout << "Target=" << target << endl;
 	    
@@ -158,7 +167,8 @@ int main(int argc, char **argv)
 
 	    
 	    Chain target = Chain();
-	    int nmatch = rep.replace(str3, target);
+	    // unsigned long nmatch =
+	    rep.replace(str3, target);
 	    
 	    // cout << target << endl;
 	    
@@ -220,7 +230,8 @@ int main(int argc, char **argv)
 	    
 	    Chain str1("MyPre:HuxBBB");
 	    
-	    int nmatch = rep.replace(str1, target);
+	    // unsigned long nmatch =
+	    rep.replace(str1, target);
 
 	    // cout << "NMAtch=" << nmatch << endl;
 	    // cout << "Place=" << target << endl;
@@ -249,7 +260,8 @@ int main(int argc, char **argv)
 	    
 	    Chain str1("MyPre:HuxBBBHuxHuxGamma");
 	    
-	    int nmatch = rep.replace(str1, target);
+	    // unsigned long nmatch =
+	    rep.replace(str1, target);
 
 	    // cout << "NMAtch=" << nmatch << endl;
 	    // cout << "Place=" << target << endl;
@@ -279,7 +291,8 @@ int main(int argc, char **argv)
 	    Chain str1("Hello.world");
 
 	    // zero len replacements before and after dot
-	    int nmatch = rep.replace(str1, target);
+	    // unsigned long nmatch =
+	    rep.replace(str1, target);
 
 	    if ( target == Chain("Hello.world") )
 		cout << "ok " << checkCount << " - Zero len replace test" << endl;
@@ -306,7 +319,8 @@ int main(int argc, char **argv)
 	    Chain str1("HelloWorld.Trash123");
 
 	    // zero len replacements before and after dot
-	    int nmatch = rep.replace(str1, target);
+	    // unsigned long nmatch =
+	    rep.replace(str1, target);
 
 	    if ( target == Chain("Trash123.HelloWorld") )
 		cout << "ok " << checkCount << " - Flip replace test" << endl;
