@@ -938,6 +938,31 @@ char Chain::operator [] (unsigned long i) const
     }
 }
 
+char Chain::operator [] (unsigned i) const
+{
+    if (i < (unsigned)_len)
+    {
+	return _buf[i];
+    }
+    else
+    {
+	throw Exception(EXLOC, "String position exceeded"); 
+    }
+}
+
+char Chain::operator [] (int i) const
+{
+    if (i < (int)_len)
+    {
+	return _buf[i];
+    }
+    else
+    {
+	throw Exception(EXLOC, "String position exceeded"); 
+    }
+}
+
+
 Chain::operator char* () const
 {
     return _buf;
