@@ -285,7 +285,7 @@ void Pager::manage()
 	}
 	case KEY_CNTRL_E:
 	{
-	    int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset; 
+	    unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset; 
 	    while ( _cmdInput[bufRow][_curCol] != 0)		
 		_curCol++;	    
 	    break;
@@ -299,7 +299,7 @@ void Pager::manage()
 	}
 	case KEY_RIGHT :
 	{
-	    int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+	    unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 	    
 	    if ( _curCol <  _cols && _cmdInput[bufRow][_curCol] != 0)		
 		_curCol++;
@@ -311,7 +311,7 @@ void Pager::manage()
 	    {
 		_curRow--;
 		
-		int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+		unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 		
 		while ( _cmdInput[bufRow][_curCol] == 0 && _curCol > 0)
 		    _curCol--;
@@ -320,7 +320,7 @@ void Pager::manage()
 	    {
 		_curOffset--;
 
-		int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+		unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 		
 		while ( _cmdInput[bufRow][_curCol] == 0 && _curCol > 0)
 		    _curCol--;
@@ -334,7 +334,7 @@ void Pager::manage()
 	    {
 		_curRow++;
 		
-		int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+		unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 				
 		while ( _cmdInput[bufRow][_curCol] == 0 && _curCol > 0)
 		    _curCol--;
@@ -343,7 +343,7 @@ void Pager::manage()
 	    {
 		_curOffset++;
 
-		int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+		unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 		
 		while ( _cmdInput[bufRow][_curCol] == 0 && _curCol > 0)
 		    _curCol--;
@@ -358,10 +358,10 @@ void Pager::manage()
 	    {
 		_curCol--;
 		
-		int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+		unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 		
 		// _debug=Chain("del rowpos=") + Chain(bufRow) + Chain("cur col=") + Chain(_curCol);
-		int i=_curCol;
+		unsigned i=_curCol;
 		while ( _cmdInput[bufRow][i] > 0 )
 		{
 		    _cmdInput[bufRow][i] = _cmdInput[bufRow][i+1];
@@ -375,16 +375,16 @@ void Pager::manage()
 	    {
 		// search for end of line input of previous line
 
-		int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+		unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 
 
 		if ( bufRow > 0 )
 		{
-		    int i=0;
+		    unsigned i=0;
 		    while ( _cmdInput[bufRow-1][i] > 0 )
 			i++;
 
-		    int j=0;
+		    unsigned j=0;
 		    while ( _cmdInput[bufRow][j] > 0 )
 			j++;
 
@@ -395,7 +395,7 @@ void Pager::manage()
 			
 			// copy tail of line to end of previous line
 			
-			int j=0;
+			unsigned j=0;
 			while ( _cmdInput[bufRow][j] > 0 )
 			{
 			    _cmdInput[bufRow-1][i] = _cmdInput[bufRow][j];
@@ -404,8 +404,8 @@ void Pager::manage()
 			}
 			
 			// shift one line up
-			for ( int i=bufRow; i<MAXCMDROW; i++)
-			    for ( int j=0; j< MAXCMDCOL; j++)
+			for ( unsigned i=bufRow; i<MAXCMDROW; i++)
+			    for ( unsigned j=0; j< MAXCMDCOL; j++)
 				_cmdInput[i][j] = _cmdInput[i+1][j];
 			
 			
@@ -418,27 +418,27 @@ void Pager::manage()
 	case KEY_RETURN:
 	{
 
-	    int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
+	    unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset;
 	    
 	    // shift one line down
-	    for ( int i=MAXCMDROW-1; i>bufRow; i--)
-		for ( int j=0; j< MAXCMDCOL; j++)
+	    for ( unsigned i=MAXCMDROW-1; i>bufRow; i--)
+		for ( unsigned j=0; j< MAXCMDCOL; j++)
 		    _cmdInput[i][j] = _cmdInput[i-1][j];
 
 	    // copy tail to next row
 	    
-	    for ( int j=_curCol; j< MAXCMDCOL; j++)
+	    for ( unsigned j=_curCol; j< MAXCMDCOL; j++)
 	    {
 		_cmdInput[bufRow+1][j-_curCol] = _cmdInput[bufRow][j];
 	    }
 	    // delete tail of next row
-	    for ( int j= MAXCMDCOL - _curCol; j< MAXCMDCOL; j++)
+	    for ( unsigned j= MAXCMDCOL - _curCol; j< MAXCMDCOL; j++)
 	    {
 		_cmdInput[bufRow+1][j] = 0;
 	    }
 
 	    // delete tail of current row
-	    for ( int j=_curCol; j< MAXCMDCOL; j++)
+	    for ( unsigned j=_curCol; j< MAXCMDCOL; j++)
 	    {
 		_cmdInput[bufRow][j] = 0;
 	    }
@@ -516,8 +516,8 @@ void Pager::manage()
 	    _curCol=0;
 	    _curOffset=0;
 	    // init
-	    for ( int i=0; i< MAXCMDROW; i++)
-		for ( int j=0; j< MAXCMDCOL; j++)
+	    for ( unsigned i=0; i< MAXCMDROW; i++)
+		for ( unsigned j=0; j< MAXCMDCOL; j++)
 		    _cmdInput[i][j] = 0;
 	    break;
 	}
@@ -705,9 +705,9 @@ void Pager::managePager()
 	case KEY_NPAGE :
 	{
 	    nextRow();
-	    int pdi=_pdi;
-	    int pci=_pci;
-	    for ( int i=0; i < PAGESIZE  - 1; i++ )
+	    unsigned pdi=_pdi;
+	    unsigned pci=_pci;
+	    for ( unsigned i=0; i < PAGESIZE  - 1; i++ )
 		nextRow();
 	    _pdi=pdi;
 	    _pci=pci;
@@ -717,10 +717,10 @@ void Pager::managePager()
 	case KEY_PPAGE :
 	{
 	    prevRow();	    
-	    int pdi=_pdi;
-	    int pci=_pci;
+	    unsigned pdi=_pdi;
+	    unsigned pci=_pci;
 
-	    for ( int i=0; i < PAGESIZE - 1; i++ )
+	    for ( unsigned i=0; i < PAGESIZE - 1; i++ )
 		prevRow();
 	    _pdi=pdi;
 	    _pci=pci;
@@ -792,19 +792,8 @@ bool Pager::nextRow()
 	_nci = _rowSelected - _vStart + HEADERSIZE;
 
 	_rowIdx++;
-
-	return true;
 	
-    }
-    else
-    {
-	// if end of outData not reached, scroll forward linewise and remember offset
-	if ( _vStart < _outData.Size() - _rows + ( HEADERSIZE + _footerSize ) )
-	{
-	    _vStart += 1;
-	    // _offset++;
-	    return true;
-	}
+	return true;	
     }
 
     return false;
@@ -864,23 +853,23 @@ void Pager::writeHeader()
     wcolor_set(stdscr, COL_HEADER, NULL);
 
     // clear line
-    for(int i = 0; i < _cols; i++) 
+    for(unsigned i = 0; i < _cols; i++) 
     {
 	mvprintw(0, i, "%s", (char*)" "); 
     } 
 
     move(0,0); 
 
-    int col=0;
+    unsigned col=0;
     Chain *pAttr = _schema.First();
-    int colPos=0;
+    unsigned colPos=0;
     while ( pAttr ) 
     {
 	Chain attr;
-	int len;
+	unsigned len;
         getAttrSpec(colPos, *pAttr, attr, len); 
 
-	if (  col + (int)attr.length() < _cols )
+	if (  col + (unsigned)attr.length() < _cols )
 	    mvprintw(0, col, "%s", (char*)attr); 
 
 	colPos++;
@@ -911,24 +900,24 @@ void Pager::writePage()
     
     wcolor_set(stdscr, COL_CONTENT, NULL);
 
-    for(int i = 0; (i< _rows - 1 -_footerSize) && (i + _vStart < _outData.Size()); i++) 
+    for(unsigned i = 0; (i< _rows - 1 -_footerSize) && (i + _vStart < _outData.Size()); i++) 
     { 
-	for(int j = 0; j < _cols; j++) 
+	for(unsigned j = 0; j < _cols; j++) 
 	{
 	    mvprintw(i + HEADERSIZE, j, "%s", (char*)" "); 
 	} 
 	
-	int col=0;
+	unsigned col=0;
 	Chain *pAttr = _schema.First();
-	int colPos=0;
+	unsigned colPos=0;
 	while ( pAttr ) 
 	{
 	    Chain attr;
-	    int len;
+	    unsigned len;
 	    getAttrSpec(colPos, *pAttr, attr, len); 
 	    
 	    Chain val = _outData[i+_vStart][colPos];
-	    if ( val != Chain()  && col + (int)val.length() < _cols )
+	    if ( val != Chain()  && col + (unsigned)val.length() < _cols )
 		mvprintw(i + HEADERSIZE, col, "%s", (char*)val); 
 	    col += len;
 	    colPos++;
@@ -936,9 +925,9 @@ void Pager::writePage()
 	} 	    
     }
 
-    for(int i = _outData.Size(); (i< _rows - 1 -_footerSize); i++) 
+    for(unsigned i = _outData.Size(); (i< _rows - 1 -_footerSize); i++) 
     { 
-	for(int j = 0; j < _cols; j++) 
+	for(unsigned j = 0; j < _cols; j++) 
 	{
 	    mvprintw(i + HEADERSIZE, j, "%s", (char*)" "); 
 	} 
@@ -967,7 +956,7 @@ void Pager::writeFooter()
 
     attron(A_REVERSE);
     attron(A_BOLD);
-    for(int i = 0; i < _cols; i++)
+    for(unsigned i = 0; i < _cols; i++)
     {
         mvprintw(_rows-_footerSize, i, "%s", (char*)" ");
     }
@@ -1007,15 +996,15 @@ void Pager::writeFooter()
 
     wcolor_set(stdscr, COL_CONTENT, NULL);
 
-    for ( int i=1; i<_footerSize; i++)
+    for ( unsigned i=1; i<_footerSize; i++)
     {
-	for(int j = 0; j < _cols; j++)
+	for(unsigned j = 0; j < _cols; j++)
 	{
 	    mvprintw(_rows-_footerSize + i, j, "%s", (char*)" ");
 	}
     }
     
-    for ( int i=0; i<_footerSize; i++)
+    for ( unsigned i=0; i<_footerSize; i++)
     {
 	mvprintw(_rows-_footerSize+i+1, 0, "%s", _cmdInput[i+ _curOffset]);
     }
@@ -1033,7 +1022,7 @@ void Pager::writeDebug()
     
     attron(A_REVERSE);
     move(_rows-1,0); 
-    for(int i = 0; i < _cols; i++) 
+    for(unsigned i = 0; i < _cols; i++) 
     { 
         addch(' '); 
     } 
@@ -1045,12 +1034,12 @@ void Pager::writeDebug()
 } 
 
 
-void Pager::refreshRow(int dataRow, int pageRow)
+void Pager::refreshRow(unsigned dataRow, unsigned pageRow)
 {
     if ( _outData.Size() == 0)
 	return;
     
-    int colno=0;
+    unsigned colno=0;
     
     // int rowColor = COL_CONTENT;
 
@@ -1063,28 +1052,28 @@ void Pager::refreshRow(int dataRow, int pageRow)
 	// rowColor = COL_SELECTED;
     }
     
-    for(int i = 0; i < _cols; i++) 
+    for(unsigned i = 0; i < _cols; i++) 
     { 
         mvwprintw(stdscr, pageRow, i, "%s", (char*)" ");
     } 
 
     Chain *pAttr = _schema.First();
-    int colPos=0;
+    unsigned colPos=0;
     Chain *pVal = _outData[dataRow].First();
     while ( pAttr && pVal )
     {		       
 	Chain attr;
-	int len;
+	unsigned len;
 	getAttrSpec(colPos, *pAttr, attr, len);
 		    
 	if ( 1 ) // perhaps later we also make right align : lenInfo[0] == 'l' )
 	{
-	    if ( *pVal && colno + (int)pVal->length() < _cols )
+	    if ( *pVal && colno + (unsigned)pVal->length() < _cols )
 		mvwprintw(stdscr, pageRow, colno, "%s", (char*)*pVal);
 	}
 	else
 	{
-	    int offset = len - (int)pVal->length();
+	    unsigned offset = len - (unsigned)pVal->length();
 	    if ( *pVal )
 		mvwprintw(stdscr, pageRow, colno+offset, "%s", (char*)*pVal);	    
 	}
@@ -1107,7 +1096,7 @@ void Pager::refreshRow(int dataRow, int pageRow)
     }
 }
 
-void Pager::getAttrSpec(int colPos, const Chain& s, Chain& attr, int& len)
+void Pager::getAttrSpec(unsigned colPos, const Chain& s, Chain& attr, unsigned& len)
 {    
     Tokenizer t1(s, ":");
     t1.nextToken(attr);
@@ -1116,12 +1105,11 @@ void Pager::getAttrSpec(int colPos, const Chain& s, Chain& attr, int& len)
     if ( attrLen == Chain("auto") )
 	len = _outLen[colPos];
     else
-	len = attrLen.asInteger();
+	len = attrLen.asUnsigned();
 }
 
 void Pager::formatData(const ListT< ListT<Chain> > & outData)
 {
-
     _outData.Empty();
     _rowHeight.Empty();
     
@@ -1130,7 +1118,7 @@ void Pager::formatData(const ListT< ListT<Chain> > & outData)
     
     while ( pRow )
     {
-	int lineNo=0;
+	unsigned lineNo=0;
 	
 	bool moreLines=true;
 	
@@ -1140,13 +1128,13 @@ void Pager::formatData(const ListT< ListT<Chain> > & outData)
 	    
 	    moreLines=false;
 
-	    int colNum=0;
+	    unsigned colNum=0;
 	    Chain *pCol = pRow->First();
 	    while ( pCol )
 	    {
 		Tokenizer tok(*pCol, "\n");
 
-		int i=0;
+		unsigned i=0;
 		Chain s;
 		bool hasToken=false;
 		while (  i <= lineNo )
@@ -1159,8 +1147,8 @@ void Pager::formatData(const ListT< ListT<Chain> > & outData)
 		    // cout << "Got token " << s << " for lineno = " << lineNo << endl;
 		    outRow.Insert(s);
 
-		    if ( _outLen[colNum] < (int)s.length() + 1 )
-			_outLen[colNum] = (int)s.length() + 1;
+		    if ( _outLen[colNum] < (unsigned)s.length() + 1 )
+			_outLen[colNum] = (unsigned)s.length() + 1;
 		    
 		    moreLines=true;
 		}
@@ -1232,10 +1220,10 @@ void Pager::addInput(int c)
 {
     if ( isCmdInput(c) )
     {
-	int bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset; 
+	unsigned bufRow = _curRow - ( _rows - _footerSize) - 1 + _curOffset; 
 	
 	// shift tail
-	int i = _curCol;
+	unsigned i = _curCol;
 	while ( _cmdInput[bufRow][i] != 0 )
 	    i++;
 
@@ -1261,7 +1249,7 @@ Chain Pager::getCommand()
 {
     Chain cmd;
     
-    for ( int i=0; i< MAXCMDROW; i++)
+    for ( unsigned i=0; i< MAXCMDROW; i++)
     {
 	Chain chunk(_cmdInput[i]);
 	if ( i ==  0 )
@@ -1276,13 +1264,13 @@ void Pager::setCommand(const Chain& cmd)
 {
     initCmd();
     
-    int i=0;
-    int row=0;
-    while ( row < MAXCMDROW && i < (int)cmd.length() )
+    unsigned i=0;
+    unsigned row=0;
+    while ( row < MAXCMDROW && i < (unsigned)cmd.length() )
     {
-	int col=0;
+	unsigned col=0;
 	bool eol=false;
-	while (  i < (int)cmd.length() && ! eol ) 
+	while (  i < (unsigned)cmd.length() && ! eol ) 
 	{	    
 	    if ( cmd[i] != '\n' )
 	    {
@@ -1299,7 +1287,7 @@ void Pager::setCommand(const Chain& cmd)
     }
 }
 
-void Pager::showHelp(int helpMode)
+void Pager::showHelp(unsigned helpMode)
 {
 
     curs_set(0);
@@ -1333,7 +1321,7 @@ void Pager::showHelp(int helpMode)
 
     box(helpwin, 0, 0);
 
-    int i=3;
+    unsigned i=3;
     if ( helpMode == HELP_PAGE )
     {
 	mvwprintw(helpwin, i++, 2, "%s",  (char*)"Up/Down - Next / Previous line");
@@ -1391,12 +1379,12 @@ void Pager::showMessage()
 
     Tokenizer tok(_msg, Chain("\n"));
     Chain token;
-    int cols = 10;
-    int rows = 3;
+    unsigned cols = 10;
+    unsigned rows = 3;
     while (tok.nextToken(token) == true)
     {	    
-	if ( (int)token.length() + 4 > cols )
-	    cols = (int)token.length() + 4;
+	if ( (unsigned)token.length() + 4 > cols )
+	    cols = (unsigned)token.length() + 4;
 	rows++;
     }
     
@@ -1434,8 +1422,6 @@ bool Pager::showSearch()
 
     curs_set(1);
     
-    // int startx, starty;
-
     
     int xoff,yoff;
     getbegyx(stdscr, yoff, xoff);
@@ -1445,22 +1431,20 @@ bool Pager::showSearch()
 
     // startx = xoff + (x / 7);
     int starty = yoff + (y / 4);
-
     
     WINDOW* searchwin = newwin( 4, MAXSEARCHLEN + 3, starty, 2);
 
     keypad(searchwin, TRUE);
   
-    int curCol = 0;
+    unsigned curCol = 0;
     wmove(searchwin, 0, 0);
     refresh();
     
-    // wmove(searchwin, 1, curcol + 1);
 
     int c = 0; // wgetch(msgwin);
 
     char searchBuffer[MAXSEARCHLEN];
-    for ( int i=0; i< MAXSEARCHLEN; i++ )
+    for ( unsigned i=0; i< MAXSEARCHLEN; i++ )
 	searchBuffer[i] = 0;
 
     do 
@@ -1486,7 +1470,7 @@ bool Pager::showSearch()
 	    {
 		curCol--;
 			       
-		int i=curCol;
+		unsigned i=curCol;
 		while ( searchBuffer[i] > 0 )
 		{
 		    searchBuffer[i] = searchBuffer[i+1];
@@ -1503,7 +1487,7 @@ bool Pager::showSearch()
 		// mvprintw(, col, "%s", (char*)_cntrl);
 
 		// shift tail
-	        int i = curCol;
+	        unsigned i = curCol;
 		while ( searchBuffer[i] != 0 )
 		    i++;
 		
@@ -1532,7 +1516,7 @@ bool Pager::showSearch()
 	box(searchwin, 0, 0);
 	
 	// clear searchbuffer
-	for(int i = 1; i < MAXSEARCHLEN+2; i++) 
+	for(unsigned i = 1; i < MAXSEARCHLEN+2; i++) 
 	{ 
 	    mvwprintw(searchwin, 2, i, "%s", (char*)" ");
 	} 
@@ -1572,13 +1556,13 @@ bool Pager::nextSearchResult(bool isFirst)
     if ( _outData.Size() == 0 )
 	return false;
     
-    int rowIdx = _rowIdx;
-    int rowSelected = _rowSelected;
-    int vStart = _vStart;
-    int pdi=_pdi;
-    int pci=_pci;    
-    int ndi = _ndi;
-    int nci = _nci;
+    unsigned rowIdx = _rowIdx;
+    unsigned rowSelected = _rowSelected;
+    unsigned vStart = _vStart;
+    unsigned pdi=_pdi;
+    unsigned pci=_pci;    
+    unsigned ndi = _ndi;
+    unsigned nci = _nci;
     
     bool moreRow=true;
     bool found=false;
@@ -1599,7 +1583,7 @@ bool Pager::nextSearchResult(bool isFirst)
 
 	// search for all line in row, also multiline rows
 	
-	int i=0;
+	unsigned i=0;
        
 	while ( ! found && i<_rowHeight[_rowIdx] )
 	{    
@@ -1630,7 +1614,7 @@ bool Pager::nextSearchResult(bool isFirst)
     return found;
 }
 
-bool Pager::matchRow(int row)
+bool Pager::matchRow(unsigned row)
 {
     Chain *pVal = _outData[row].First();
     while ( pVal )
@@ -1654,7 +1638,7 @@ int Pager::addHist(const Chain& cmd)
 
 void Pager::initCmd()
 {
-    for ( int i=0; i< MAXCMDROW; i++)
-	for ( int j=0; j< MAXCMDCOL; j++)
+    for ( unsigned i=0; i< MAXCMDROW; i++)
+	for ( unsigned j=0; j< MAXCMDCOL; j++)
 	    _cmdInput[i][j] = 0;
 }
