@@ -35,7 +35,7 @@ Tokenizer::Tokenizer(const Chain& tokenStream, const Chain& sep, char esc)
     _upper = 0;
 }
 
-Tokenizer::Tokenizer(char* buf, int len, const Chain& sep, char esc)
+Tokenizer::Tokenizer(char* buf, unsigned long len, const Chain& sep, char esc)
 {
     _streamBuf = buf;
     _bufLen = len;
@@ -52,22 +52,21 @@ Tokenizer::~Tokenizer()
 
 bool Tokenizer::nextToken(Chain& token)
 {
-
     if ( _bufLen <= _upper)
 	return false;
 
-    int si;
+    unsigned long si;
 
     bool sepFound = true;
 
     // skip through sep
-
+    
     while (sepFound == true)
     {
 	sepFound = false;
 
 	si=0;
-	while (sepFound == false && si < (int)_sep.length()-1)
+	while (sepFound == false && si < _sep.length()-1)
 	{
 	    char c;
 	    c = _sep[si];
@@ -83,7 +82,7 @@ bool Tokenizer::nextToken(Chain& token)
 	    _upper++;
 	}
     }
-
+    
     _lower = _upper;
 
     while (sepFound  == false && _streamBuf[_upper])
@@ -120,8 +119,6 @@ bool Tokenizer::nextToken(Chain& token)
     
     token = Chain(_streamBuf + _lower, _upper - _lower);
     
-    // token = _tokenStream.subChain(_lower+1, _upper);
-
     _lower = _upper;
     
     return true;
@@ -130,8 +127,8 @@ bool Tokenizer::nextToken(Chain& token)
 bool Tokenizer::checkSeparator()
 {
     bool sepFound=false;
-    int si=0;
-    while ( sepFound == false  && si < (int)_sep.length()-1)
+    unsigned long si=0;
+    while ( sepFound == false  && si < _sep.length()-1)
     {			      
 	char c;	
 	c = _sep[si];
@@ -155,13 +152,13 @@ bool Tokenizer::getTail(Chain& token)
 
 }
 
-void Tokenizer::skip(int n)
+void Tokenizer::skip(unsigned long n)
 {
     _upper += n;
     _lower = _upper;
 }
 
-bool Tokenizer::rawRead(Chain& token, int n)
+bool Tokenizer::rawRead(Chain& token, unsigned long n)
 {    
     if ( _bufLen < _upper + n)
 	return false;
@@ -173,7 +170,7 @@ bool Tokenizer::rawRead(Chain& token, int n)
     return true;
 }
 
-int Tokenizer::numAhead() const
+unsigned long Tokenizer::numAhead() const
 {
     return _bufLen - _lower - 1;
 }
@@ -184,7 +181,7 @@ void Tokenizer::reset()
     _upper = 0;
 }
 
-void Tokenizer::reset(char* buf, int len)
+void Tokenizer::reset(char* buf, unsigned long len)
 {
     _streamBuf = buf;
     _bufLen = len;
